@@ -54,6 +54,62 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateAutoCalloutTask(self, request):
+        """创建自动外呼任务
+
+        :param request: Request instance for CreateAutoCalloutTask.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAutoCalloutTaskRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAutoCalloutTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateAutoCalloutTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateAutoCalloutTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateCallOutSession(self, request):
+        """创建外呼会话
+
+        :param request: Request instance for CreateCallOutSession.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateCallOutSessionRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateCallOutSessionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateCallOutSession", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateCallOutSessionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSDKLoginToken(self, request):
         """创建 SDK 登录 Token。
 
@@ -166,6 +222,118 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAutoCalloutTask(self, request):
+        """查询自动外呼任务详情
+
+        :param request: Request instance for DescribeAutoCalloutTask.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTaskRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAutoCalloutTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAutoCalloutTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeAutoCalloutTasks(self, request):
+        """批量查询自动任务外呼
+
+        :param request: Request instance for DescribeAutoCalloutTasks.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTasksRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAutoCalloutTasks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAutoCalloutTasksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeCCCBuyInfoList(self, request):
+        """获取用户购买信息列表
+
+        :param request: Request instance for DescribeCCCBuyInfoList.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeCCCBuyInfoListRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeCCCBuyInfoListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCCCBuyInfoList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCCCBuyInfoListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeCallInMetrics(self, request):
+        """获取呼入实时数据统计指标
+
+        :param request: Request instance for DescribeCallInMetrics.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeCallInMetricsRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeCallInMetricsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCallInMetrics", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCallInMetricsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeChatMessages(self, request):
         """包括具体聊天内容
 
@@ -250,6 +418,34 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeProtectedTelCdr(self, request):
+        """获取主被叫受保护的电话服务记录与录音
+
+        :param request: Request instance for DescribeProtectedTelCdr.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeProtectedTelCdrRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeProtectedTelCdrResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeProtectedTelCdr", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeProtectedTelCdrResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSeatUserList(self, request):
         """废弃接口下架
 
@@ -336,6 +532,34 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeStaffStatusMetrics(self, request):
+        """获取坐席实时状态统计指标
+
+        :param request: Request instance for DescribeStaffStatusMetrics.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusMetricsRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusMetricsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeStaffStatusMetrics", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeStaffStatusMetricsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTelCallInfo(self, request):
         """按实例获取电话消耗统计
 
@@ -420,6 +644,34 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def StopAutoCalloutTask(self, request):
+        """停止自动外呼任务
+
+        :param request: Request instance for StopAutoCalloutTask.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.StopAutoCalloutTaskRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.StopAutoCalloutTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StopAutoCalloutTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopAutoCalloutTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UnbindStaffSkillGroupList(self, request):
         """解绑坐席所属技能组
 
