@@ -57,7 +57,12 @@ class TiiaClient(AbstractClient):
 
 
     def CreateGroup(self, request):
-        """用于创建一个空的图片库，如果图片库已存在则返回错误。
+        """用于创建一个空的图片库，如果图片库已存在则返回错误。不同类型图库对应不同的图像搜索服务，根据输入参数GroupType区分。
+
+        | 服务类型 |  功能描述 |
+        |  :------  | :-----------------  |
+        | 相同图像搜索<img width=30/>    | 在自建图库中搜索相同原图，可支持裁剪、翻转、调色、加水印后的图片搜索，适用于版权场景。|
+        | 商品图像搜索<img width=30/>   | 在自建图库中搜索相同或相似的商品图片，适用于电商场景。|
 
         :param request: Request instance for CreateGroup.
         :type request: :class:`tencentcloud.tiia.v20190529.models.CreateGroupRequest`
@@ -525,6 +530,37 @@ class TiiaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RecognizeCarPro(self, request):
+        """车辆识别（增强版）可对图片中汽车的车型和车牌进行识别，可识别7000多种车型，覆盖轿车、SUV、大型客车等市面常见车，输出车辆的车身颜色、品牌、车系、年份、车牌和位置等信息。如果图片中存在多辆车，会分别输出每辆车的车型、车牌和坐标。
+
+        >
+        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。
+
+        :param request: Request instance for RecognizeCarPro.
+        :type request: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarProRequest`
+        :rtype: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarProResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RecognizeCarPro", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RecognizeCarProResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SearchImage(self, request):
         """本接口用于对一张待识别的商品图片，在指定图片库中检索出最相似的图片列表。
 
